package com.xy.satoken;

import lombok.AllArgsConstructor;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.config.annotation.InterceptorRegistration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
 * 单体boot鉴权
 */
@Component
@AllArgsConstructor
@ConditionalOnExpression("'${sa-token.run-way}'.equals('boot')")
public class SaTokenWebMvcConfigurer extends HandlerInterceptorAdapter implements WebMvcConfigurer {

    private SaTokenAuthorizeConfig saTokenAuthorizeConfig;

    private SaTokenAuthorize saTokenAuthorize;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        String permission = request.getRequestURI();
        String satoken = request.getHeader(saTokenAuthorizeConfig.getTokenName());
        return saTokenAuthorize.check(satoken, permission);
    }


    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        List<String> swaggerExcludes = Arrays.asList(
                "/swagger/**",
                "/v2/**",
                "/doc.html/**",
                "/v3/**",
                "/swagger-resources/**",
                "/webjars/**",
                "/swagger-ui/**",
                "/favicon.ico"
        );
        InterceptorRegistration interceptorRegistration = registry.addInterceptor(this)
                .excludePathPatterns(swaggerExcludes)
                .addPathPatterns("/**");
        List<String> excludePaths = saTokenAuthorizeConfig.getExcludePaths();
        if (excludePaths != null) {
            excludePaths.forEach(excludePath -> interceptorRegistration.excludePathPatterns("/**" + excludePath));
        }
    }

}
